@@ -99,6 +99,18 @@ class ArgParser(argparse.ArgumentParser):
             "-V", "--validate_urls",
             action='store_true',
             help='Check generated list of URLs as valid download locations')
+        self.add_argument(
+            "-A", "--available_remote_data",
+            action='store_true',
+            help='list data retrievable from histdata.com')
+        self.add_argument(
+            "-U", "--update_remote_data",
+            action='store_true',
+            help='update list of data retrievable from histdata.com')
+        self.add_argument(
+            '--by',
+            type=str,
+            help='for use with -A and -U, to sort output --by [pair_asc, pair_dsc, start_asc, start_dsc]')
         self.add_argument(
             "-D", "--download_data_archives",
             action='store_true',
@@ -145,7 +157,15 @@ class ArgParser(argparse.ArgumentParser):
             type=(lambda v: self.validate_yearmonth_format(v)),
             help='set a start year and month for data. e.g. -e 2020-00 or -e 2022-04')
         self.add_argument(
-            '-d', '--data-directory',
+            '-b', '--batch_size',
+            type=int,
+            help='(integer) influxdb write_api batch size. defaults to 5000')
+        self.add_argument(
+            '-d', '--delete_after_influx',
+            action='store_true',
+            help='delete data files after upload to influxdb')
+        self.add_argument(
+            '--data-directory',
             type=str,
             help='Directory Used to save data. default is "data" in the current directory')
 
@@ -154,6 +174,8 @@ class ArgParser(argparse.ArgumentParser):
             self.print_help(sys.stderr)
             sys.exit(1)
 
+        self.adjust_for_repo_data_request(self.arg_namespace)
+
         if "histdatacom" not in sys.argv[0] and self.arg_namespace.from_api:
             args = self.clean_from_api_args(self.arg_namespace)
             self.false_from_api_if_behavior_flag(self.arg_namespace)
@@ -173,20 +195,38 @@ class ArgParser(argparse.ArgumentParser):
         """ simply return the completed args object """
         return self.arg_namespace
 
+    @classmethod
+    def adjust_for_repo_data_request(cls, args_namespace):
+        if args_namespace.available_remote_data \
+        or args_namespace.update_remote_data:
+            args_namespace.start_yearmonth = None
+            args_namespace.end_yearmonth = None
+            args_namespace.validate_urls = False
+            args_namespace.download_data_archives = False
+            args_namespace.extract_csvs = False
+            args_namespace.import_to_influxdb = False
+            args_namespace.formats = {"ascii"}
+            args_namespace.timeframes = {"tick-data-quotes"}
+
     @classmethod
     def clean_from_api_args(cls, args_namespace):
         args = []
 
-        args.extend(["-d", args_namespace.data_directory])
+        args.extend(["--data-directory", args_namespace.data_directory])
         args.extend(["-p", *args_namespace.pairs])
         args.extend(["-f", *args_namespace.formats])
         args.extend(["-t", *args_namespace.timeframes])
         args.extend(["-c", args_namespace.cpu_utilization])
+        args.extend(["-b", args_namespace.batch_size])
 
         if args_namespace.start_yearmonth:
             args.extend(["-s", args_namespace.start_yearmonth])
         if args_namespace.end_yearmonth:
             args.extend(["-e", args_namespace.end_yearmonth])
+        if args_namespace.available_remote_data:
+            args.append("-A")
+        if args_namespace.update_remote_data:
+            args.append("-U")
         if args_namespace.validate_urls:
             args.append("-V")
         if args_namespace.download_data_archives:
@@ -195,6 +235,8 @@ class ArgParser(argparse.ArgumentParser):
             args.append("-X")
         if args_namespace.import_to_influxdb:
             args.append("-I")
+        if args_namespace.delete_after_influx:
+            args.append("-d")
         return args
 
     @classmethod
@@ -213,6 +255,7 @@ class ArgParser(argparse.ArgumentParser):
         or args_namespace.import_to_influxdb:
             args_namespace.from_api = False
 
+
     @classmethod
     def check_for_ascii_if_influx(cls, args_namespace):
         """Verify ascii csv_format type for influxdb import"""
