@@ -47,8 +47,10 @@ class _HistDataCom:
         self.csvs = _CSVs()
         self.api = _API()
 
-        if config.args['available_remote_data'] and self.urls.test_for_repo_data_file():
-            self.urls.read_repo_data_file()
+        if (config.args['available_remote_data'] or config.args['update_remote_data']):
+            if self.urls.test_for_repo_data_file():
+                self.urls.read_repo_data_file()
+            self.urls.update_repo_from_github()
 
         if config.args["import_to_influxdb"] == 1:
             self.influx = _Influx()
