@@ -3,6 +3,7 @@ import sys
 import pickle
 import contextlib
 from urllib.parse import urlparse
+from urllib.request import urlopen
 import requests
 from rich import print
 from rich.progress import Progress
@@ -16,6 +17,8 @@ from histdatacom.utils import get_month_from_datemonth
 from histdatacom.utils import get_current_datemonth_gmt_minus5
 from histdatacom.utils import force_datemonth_if_only_year
 from histdatacom.utils import create_full_path
+from histdatacom.utils import hash_dict
+from histdatacom.utils import get_now_UTC_timestamp
 from histdatacom.fx_enums import Timeframe
 from histdatacom.fx_enums import get_valid_format_timeframes
 from histdatacom.records import Record
@@ -40,7 +43,7 @@ class _URLs:
             "Referer": "",
             "Accept-Encoding": "gzip, deflate",
             "Accept-Language": "en-US,en;q=0.9"}
-
+        config.args["repo_url"] = "https://github.com/dmidlo/histdata.com-tools/blob/main/data/.repo?raw=true"
 
     def populate_initial_queue(self):
         with Progress(TextColumn(text_format="[cyan] Generating API Requests"),
@@ -48,10 +51,15 @@ class _URLs:
                       TimeElapsedColumn()) as progress:
             task_id = progress.add_task("waiting", total=0)
 
+            if config.filter_pairs is None\
+            and not (config.args['update_remote_data']\
+            and config.args['available_remote_data']):
+                config.filter_pairs = config.args["pairs"]
+
             for url in self.generate_form_urls(config.args["start_yearmonth"],
                                             config.args["end_yearmonth"],
                                             config.args['formats'],
-                                            config.args["pairs"],
+                                            config.filter_pairs,
                                             config.args['timeframes'],
                                             config.args["base_url"]):
                 record = Record()
@@ -60,7 +68,7 @@ class _URLs:
 
                 if record.status != "URL_NO_REPO_DATA":
                     record.write_info_file(base_dir=config.args['default_download_dir'])
-                    if (config.args['update_remote_data'] or\
+                    if (config.args['update_remote_data'] or config.filter_pairs or\
                     (config.args['available_remote_data'] and not config.repo_data_file_exists))\
                     and record.status != "URL_NEW":
                         self.set_available_data(record)
@@ -77,7 +85,7 @@ class _URLs:
                 if record.data_tk == "":
                     raise ValueError
 
-                if config.args['update_remote_data'] or \
+                if config.args['update_remote_data'] or len(config.filter_pairs) > 0 or\
                   (config.args['available_remote_data'] and not config.repo_data_file_exists):
                     self.set_available_data(record)
 
@@ -90,8 +98,8 @@ class _URLs:
                 print(f"Info: Histdata.com does not have: {record.url}")
             record.status = "URL_NO_REPO_DATA"
             record.write_info_file(base_dir=args['default_download_dir'])
-        except Exception:
-            print(f"Unknown Error for URL: {record.url}", sys.exc_info())
+        except Exception as e:
+            print(f"Unknown Error for URL: {record.url}", sys.exc_info(e))
             record.delete_info_file()
             raise
         finally:
@@ -242,12 +250,24 @@ class _URLs:
         if os.path.exists(f"{config.args['default_download_dir']}{os.sep}.repo"):
             config.repo_data_file_exists = True
             return True
+
         config.repo_data_file_exists = False
         return False
 
+    @classmethod
+    def hash_repo(cls):
+        if 'hash' in config.available_remote_data:
+                del config.available_remote_data['hash']
+        if 'hash_utc' in config.available_remote_data:
+            del config.available_remote_data['hash_utc']
+        config.available_remote_data['hash'] = hash_dict(config.available_remote_data)
+        config.available_remote_data['hash_utc'] = get_now_UTC_timestamp()
+
     @classmethod
     def write_repo_data_file(cls):
         try:
+            cls.hash_repo()            
+
             path = config.args['default_download_dir']
             create_full_path(path)
 
@@ -264,6 +284,30 @@ class _URLs:
                 while True:
                     config.available_remote_data.update(pickle.load(fileread))
 
+
+    @classmethod
+    def update_repo_from_github(cls):
+        try:
+            remote_repo = pickle.load(urlopen(config.args["repo_url"]))
+            remote_hash = remote_repo['hash']
+            remote_time = remote_repo['hash_utc']
+
+            if config.repo_data_file_exists:
+                old_hash = config.available_remote_data['hash']
+                old_time = config.available_remote_data['hash_utc']
+
+                if old_hash != remote_hash and old_time < remote_time:
+                    config.available_remote_data = remote_repo
+            else:
+                config.available_remote_data = remote_repo
+                print(config.available_remote_data)
+                config.repo_data_file_exists = True
+                cls.write_repo_data_file()
+        except Exception as e:
+            print(f"Unable to fetch repo list from github: {record.url}", sys.exc_info(e))
+       
+
+
     def print_repo_data_table(self):
         table = Table(title="Data and date ranges available from HistData.com",
                       box=box.MARKDOWN)
@@ -281,12 +325,17 @@ class _URLs:
         print(table)
 
     def get_available_repo_data(self):
+        filter_pairs = config.args['pairs'] - set(config.available_remote_data)
+        config.filter_pairs = None if len(filter_pairs) == 0 else filter_pairs
+
         if (not config.repo_data_file_exists and config.args['available_remote_data'])\
-            or config.args['update_remote_data']:
+            or config.args['update_remote_data']\
+            or config.filter_pairs:
             self.populate_initial_queue()
 
         if config.args['available_remote_data'] or config.args['update_remote_data']:
-            if config.args['update_remote_data'] or not config.repo_data_file_exists:
+            if config.args['update_remote_data'] or not config.repo_data_file_exists\
+                or config.filter_pairs:
                 self.validate_urls()
                 self.write_repo_data_file()
 
@@ -298,12 +347,8 @@ class _URLs:
 
     @classmethod
     def filter_repo_dict_by_pairs(cls, repo_dict_copy, filter_pairs):
-        filtered = dict()
-        for x in repo_dict_copy:
-            for y in filter_pairs:
-                if x == y:
-                    filtered.update({x: {"start": repo_dict_copy[x]['start'], "end": repo_dict_copy[x]['end']}})
-
+        filtered = {x: {"start": repo_dict_copy[x]['start'], "end": repo_dict_copy[x]['end']}
+                    for x in set(repo_dict_copy) & filter_pairs}
 
         return filtered if len(filter_pairs) > 0 else repo_dict_copy
 
